import React, { forwardRef, memo, useEffect, useState } from 'react';
import { Button, Col, Dropdown, Icon, Input, Row } from 'antd';
import { ChromePicker } from 'react-color';
import { propsAreEqual } from '../utils';
function StringComponent(props, ref) {
    const { value, isShowInput = true, isShowColor = false, colorType = 'hex', onChange, children, isFont, style, rowProps = { gutter: 5 }, inputColProps = { span: 18 }, colorColProps = { span: 6 }, inputProps = {}, } = props;
    const [color, setColor] = useState(value);
    useEffect(() => {
        setColor(value);
    }, [value]);
    useEffect(() => {
        let timer = setTimeout(() => onChange && onChange(color), 100);
        return () => clearTimeout(timer);
    }, [color]);
    function handleChangeColor(value) {
        let color;
        if (value.target) {
            color = value.target.value;
        }
        else {
            const { rgb: { r, g, b, a }, hex } = value;
            color = colorType === 'hex' ? hex : `rgba(${r},${g},${b},${a})`;
        }
        setColor(color);
    }
    const childNode = children || isFont && React.createElement(Icon, { type: 'font-colors' });
    const colorStyle = childNode ? { color, fontSize: 16 } : { backgroundColor: color };
    return (React.createElement(Row, Object.assign({}, rowProps),
        isShowInput && React.createElement(Col, Object.assign({}, inputColProps),
            React.createElement(Input, Object.assign({ allowClear: true, size: 'small', value: color, onChange: handleChangeColor }, inputProps))),
        isShowColor && React.createElement(Col, Object.assign({}, colorColProps),
            React.createElement(Dropdown, { trigger: ['click'], overlay: React.createElement(ChromePicker, { color: color, onChange: handleChangeColor }) },
                React.createElement(Button, { size: 'small', style: { width: '100%', ...style, ...colorStyle } }, childNode)))));
}
export default memo(forwardRef(StringComponent), propsAreEqual);
